@@ -102,7 +102,8 @@ Controller <- BaseTrait$proto(class=c("Controller", BaseTrait$class),
                                                    property=i$property,
                                                    view_widget_name=i$view_widget_name,
                                                    add_handler_name=i$add_handler_name,
-                                                   handler_user_data=i$handler_user_data
+                                                   handler_user_data=i$handler_user_data,
+                                                   by_index=.$by_index
                                                    )
                                    })
                                  }
@@ -130,16 +131,31 @@ Controller <- BaseTrait$proto(class=c("Controller", BaseTrait$class),
                                  sapply(nms[grep("property_(.*)_value_changed$", nms)],
                                         function(i) {
                                           prop <-  gsub("property_(.*)_value_changed$","\\1",i)
-                                          .$get_slot(i)(., .$get_model()$getattr(prop),NA)
+##                                          XXX changed so that value is coerced -- didn't work
+                                          meth_name <- sprintf("get_%s",prop)
+                                          if(.$has_slot(meth_name))
+                                            value <- do.call(meth_name,list(.))
+                                          else
+                                            value <- .$get_model()$getattr(prop)
+                                          .$get_slot(i)(., value, NA)
+##                                          .$get_slot(i)(., .$get_model()$getattr(prop),NA)
                                         })
                                  invisible()
                                },
-                               ## when a model changes, this function is called
-                               ## if the controller is an observer
+                              ## when a model changes, this function is called
+                              ## if the controller is an observer
+                              .doc_model_value_changed=paste(
+                                desc("Method called when any item in the model is changed")
+                                ),
                               ## model_value_changed= function(.) {},
 
-                               ## When a property of a model is changed through set_PROPERTYNAME
-                               ## then methods of this type are called
+                              ## When a property of a model is changed through set_PROPERTYNAME
+                              ## then methods of this type are called
+                              .doc_property_PROPERTYNAME_value_changed=paste(
+                                desc("Method called when property <code>PROPERTYNAME</code>is changed"),
+                                param("value","New value (raw value, not coerced)"),
+                                param("old_value", "Old value of property")
+                                ),
                               ## property_PROPERTYNAME_value_changed = function(., value, old_value,...) {},
 
                                ## Private properties
@@ -191,7 +207,8 @@ Adapter <- Controller$proto(class=c("Adapter", Controller$class),
                                                 . <- h$action$adapter
                                                 
                                                 ## set property in model using name
-                                                value <- svalue(h$obj)
+                                                index <- get_with_default(.$get_slot("by_index"), FALSE)
+                                                value <- svalue(h$obj, index=index)
 
                                                 ## XXX added check here, not sure why it is needed. 
                                                 if(isExtant(h$obj) && !is.null(value)) {
